export declare class Logger {
    readonly className: string;
    constructor(className?: string);
    private _log;
    /**
     * Starts log group and logs to console
     * @param {string} methodeName The methods where the logging takes place
     * @param {string} description The log message or description
     */
    group(methodeName: string, description: string): Logger;
    groupEnd(): Logger;
    /**
     * Logs to the console
     * @param {string} methodeName The methods where the logging takes place
     * @param {string} description The log message or description
     * @param {unknown} object An optional objects which gets printed to the console
     * @return {Logger} Returns logger
     */
    log(methodeName: string, description: string, object?: unknown): Logger;
    /**
     * Log info to the console
     * @param {string} methodeName The methods where the logging takes place
     * @param {string} description The log message or description
     * @param {unknown} object An optional objects which gets printed to the console
     * @return {Logger} Returns logger
     */
    info(methodeName: string, description: string, object?: unknown): Logger;
    /**
     * Log warning to the console
     * @param {string} methodeName The methods where the logging takes place
     * @param {string} description The log message or description
     * @param {unknown} object An optional objects which gets printed to the console
     * @return {Logger} Returns logger
     */
    warning(methodeName: string, description: string, object?: unknown): Logger;
    /**
     * Log error the console
     * @param {string} methodeName The methods where the logging takes place
     * @param {string} description The log message or description
     * @param {unknown} object An optional objects which gets printed to the console
     * @return {Logger} Returns logger
     */
    error(methodeName: string, description: string, object?: unknown): Logger;
}
export declare const loggers: Map<string, Logger>;
export declare let genericLogger: Logger | undefined;
export declare function loggerOf(className?: string): Logger;
export declare class LogHelper {
    private static maximalLogSize;
    private static overflowRemoveCount;
    private static log;
    /**
     * Gets a copy of the log
     * @return {string[]} Copy of the log
     */
    static getLog(): string[];
    private static setLog;
    /**
     * Adds a string to the log
     * @param {string} log A string to add to the log
     */
    static add(log: string): void;
    /**
     * Remove a line in the log
     * @param {number} index The line to be removed
     */
    static remove(index: number): void;
    /**
     * Removes the complete log
     */
    static removeAll(): void;
    /**
     * Gets the log size
     * @return {number} Returns the log size
     */
    static size(): number;
    /**
     * Checks if entries exists
     * @return {boolean}Returns <code>true</code> if local storage is empty, <code>false</code> if not
     */
    static isEmpty(): boolean;
    /**
     * Checks if entries exists
     * @return {boolean} Returns <code>false</code> if local storage is empty, <code>true</code> if not
     */
    static hasEntries(): boolean;
}
//# sourceMappingURL=logger.d.ts.map